==> haskell-microlens-aeson-2.5.2-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-Bpzn1TtQOik1Ou8wxLrAC3
key:                  microlens-aeson-2.5.2-Bpzn1TtQOik1Ou8wxLrAC3
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  9f3761a8285fe6d0961454563c724846
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-Bpzn1TtQOik1Ou8wxLrAC3
depends:
    aeson-2.1.2.1-nFo3VMHABFBaVDPPKfnuT
    attoparsec-0.14.4-53YjHEyIcZv40S6MstOLSz base-4.17.2.1
    bytestring-0.11.5.3 hashable-1.4.4.0-JPfSbBrFTKBgQKoWbpACz
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    scientific-0.3.7.0-H4Og6N92k1lGQSMIPZo0fR text-2.0.2
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.5.2-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-3BZYiJmpBVpBZLgO2rY6Bh
key:                  microlens-aeson-2.5.2-3BZYiJmpBVpBZLgO2rY6Bh
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  55d34ba498c02b8f697d3b8f4d8b8483
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-3BZYiJmpBVpBZLgO2rY6Bh
depends:
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB
    attoparsec-0.14.4-CvEJsUQt6CCDts1bkyqJXU base-4.17.2.1
    bytestring-0.11.5.3 hashable-1.4.4.0-4IkOt4KzeSSA3Xc4u5PLaT
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx text-2.0.2
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
